@@ -430,6 +430,8 @@ sparse_allocation <- function(
 #' @param nrows Numeric vector with the number of rows field at each location.
 #' @param ncols Numeric vector with the number of columns field at each location.
 #' @param seed (optional) Real number that specifies the starting seed to obtain reproducible designs.
+#' @param spread_reps A logical value indicating whether to maximize the spatial 
+#'   distance between replicated treatments in the field. Default is \code{TRUE}.
 #' @param optim_list (optional) A list object of class "MultiPrep"generated by \code{do_optim()} function.
 #' @param data (optional) Data frame with 2 columns: \code{ENTRY | NAME }. ENTRY must be numeric.
 #' 
@@ -507,6 +509,7 @@ multi_location_prep <- function(
     locationNames,
     optim_list, 
     seed,
+    spread_reps = TRUE,
     data = NULL) {
     # set a random seed if it is missing
     if (missing(seed)) seed <- base::sample.int(10000, size = 1)
@@ -588,9 +591,17 @@ multi_location_prep <- function(
         locationNames = locationNames,
         exptName = exptName,
         seed = seed,
+        spread_reps = spread_reps,
         multiLocationData = TRUE,
+        dist_method = "euclidean",
+        border_penalization = 0.5,
         data = preps$list_locs
     )
+    # Add this guard immediately after:
+    if (is.null(design_randomization) || is.null(design_randomization$fieldBook)) {
+        return(invisible(NULL))
+    }
+    field_book_with_rep <- add_rep_column(df = design_randomization$fieldBook)
     design_randomization$infoDesign$id_design <- "MultiPrep"
     output <- list(
         infoDesign = design_randomization$infoDesign,
@@ -604,7 +615,7 @@ multi_location_prep <- function(
         genEntries = design_randomization$genEntries,
         treatments_with_reps = design_randomization$treatments_with_reps,
         treatments_with_no_reps = design_randomization$treatments_with_no_reps,
-        fieldBook = design_randomization$fieldBook,
+        fieldBook = field_book_with_rep,
         multi_location_data = preps$multi_location_data, 
         list_locs = preps$list_locs, 
         allocation = preps$allocation, 
