@@ -87,6 +87,18 @@ mod_multi_loc_preps_ui <- function(id){
                     )
                 )
             ),
+            
+            # sliderInput(ns("border_penalization_prep"), 
+            #             label = "Border Penalization", 
+            #             min = 0.00, 
+            #             max = 1.00, 
+            #             value = 0.3),
+            # selectInput(
+            #   ns("optimization_distance_method_prep"), 
+            #   label = "Optimization Distance Method:", 
+            #   choices = c("Euclidean" = "euclidean", "Manhattan" = "manhattan"), 
+            #   selected = "manhattan"
+            # ),
             fluidRow(
                 column(
                     width = 6, 
@@ -884,6 +896,8 @@ mod_multi_loc_preps_server <- function(id){
                 planter = movement_planter,
                 seed = preps_seed, 
                 multiLocationData = TRUE,
+                dist_method = "euclidean", #input$optimization_distance_method_prep,
+                border_penalization = 0.5, #input$border_penalization_prep,
                 data = entry_list
             )
         })
@@ -1061,7 +1075,8 @@ mod_multi_loc_preps_server <- function(id){
         set.seed(seed_prep)
         for (sites in 1:locs) {
             df_loc <- subset(df.prep, LOCATION == loc_levels_factors[w])
-            fieldBook <- df_loc[, c(1,6,7,9)]
+            # fieldBook <- df_loc[, c(1,6,7,9)]
+            fieldBook <- df_loc |> dplyr::select(ID, ROW, COLUMN, ENTRY)
             dfSimulation <- AR1xAR1_simulation(
                 nrows = nrows_prep[sites], 
                 ncols = ncols_prep[sites], 
@@ -1078,7 +1093,7 @@ mod_multi_loc_preps_server <- function(id){
           dfSimulationList[[sites]] <- dfSimulation
           dataPrep <- df_loc
           df_prep <- cbind(dataPrep, round(dfSimulation[,7],2))
-          colnames(df_prep)[11] <- as.character(valsPREP$trail.prep)
+          colnames(df_prep)[12] <- as.character(valsPREP$trail.prep)
           df.prep_list[[sites]] <- df_prep
           w <- w + 1
         }
